@@ -40,7 +40,7 @@ from typing import Any, Dict, List, Optional, Tuple, Union
 # 3rd party
 import requests  # nodep
 from apeye.url import URL
-from bs4 import BeautifulSoup  # type: ignore
+from bs4 import BeautifulSoup  # type: ignore[import]
 from docutils import nodes
 from docutils.nodes import system_message
 from docutils.parsers.rst.states import Inliner
@@ -114,8 +114,6 @@ class IssueNodeWithName(IssueNode):
 	:param repo_name: The full name of the repository, in the form ``owner/name``.
 	:param issue_number: The number of the issue or pull request.
 	:param refuri: The URL of the issue / pull request on GitHub.
-
-	.. clearpage::
 	"""
 
 	repo_name: str
@@ -136,7 +134,7 @@ class IssueNodeWithName(IssueNode):
 		nodes.reference.__init__(self, source, source, refuri=self.issue_url)
 
 	@property
-	def _copy_kwargs(self):  # pragma: no cover
+	def _copy_kwargs(self) -> Dict[str, Any]:  # pragma: no cover
 		return {"repo_name": self.repo_name, "issue_number": self.issue_number, "refuri": self.issue_url}
 
 
@@ -165,6 +163,8 @@ def issue_role(
 		To be interpreted by the function.
 
 	:return: A list containing the created node, and a list containing any messages generated during the function.
+
+	.. latex:clearpage::
 	"""
 
 	has_t, issue_number, repository = split_explicit_title(text)
@@ -220,8 +220,6 @@ def pull_role(
 		To be interpreted by the function.
 
 	:return: A list containing the created node, and a list containing any messages generated during the function.
-
-	.. clearpage::
 	"""
 
 	has_t, issue_number, repository = split_explicit_title(text)
