@@ -77,9 +77,8 @@ Usage
 
 		See :mod:`sphinx_toolbox.github` for more information.
 
-	.. latex:vspace:: 5px
 
-	**Example**
+	:bold-title:`Example`
 
 	.. rest-example::
 
@@ -89,7 +88,6 @@ Usage
 			:conda-channels: domdfcoding,conda-forge
 			:github:
 
-.. latex:clearpage::
 
 
 .. rst:directive:: extensions
@@ -122,9 +120,7 @@ Usage
 		.. versionadded:: 0.4.0
 
 
-	.. latex:vspace:: 10px
-
-	**Example**
+	:bold-title:`Example`
 
 	.. rest-example::
 
@@ -136,8 +132,6 @@ Usage
 			sphinx-prompt
 
 
-.. latex:clearpage::
-
 API Reference
 --------------
 """  # noqa: D400
@@ -179,13 +173,12 @@ from domdf_python_tools.paths import PathPlus
 from domdf_python_tools.stringlist import StringList
 from domdf_python_tools.words import word_join
 from sphinx.application import Sphinx
-from sphinx.config import Config
 from sphinx.environment import BuildEnvironment
 from sphinx.util.docutils import SphinxDirective
 
 # this package
 from sphinx_toolbox import _css
-from sphinx_toolbox.utils import OptionSpec, Purger, SphinxExtMetadata, flag, metadata_add_version
+from sphinx_toolbox.utils import Config, OptionSpec, Purger, SphinxExtMetadata, flag, metadata_add_version
 
 __all__ = [
 		"InstallationDirective",
@@ -239,6 +232,9 @@ class Sources(List[Tuple[str, str, Callable, Callable, Optional[Dict[str, Callab
 	* ``getter_function`` -- the function that returns the installation instructions,
 	* ``validator_function`` -- a function to validate the option value provided by the user,
 	* ``extra_options`` -- a mapping of additional options for the directive that are used by the getter_function.
+
+	.. autoclasssumm:: Sources
+		:autosummary-sections: ;;
 	"""
 
 	def __init__(self, *args, **kwargs):
@@ -422,7 +418,7 @@ class InstallationDirective(SphinxDirective):
 	optional_arguments: int = 1  # The name of the project; can be overridden for each source
 
 	# Registered sources
-	option_spec: OptionSpec = {  # type: ignore
+	option_spec: OptionSpec = {  # type: ignore[assignment]
 		source[0].lower(): source[3]
 		for source in sources  # pylint: disable=not-an-iterable
 		}
@@ -430,7 +426,7 @@ class InstallationDirective(SphinxDirective):
 	# Extra options for registered sources
 	for source in sources:  # pylint: disable=not-an-iterable
 		if source[4] is not None:
-			option_spec.update(source[4])  # type: ignore
+			option_spec.update(source[4])  # type: ignore[attr-defined]
 
 	options: Dict[str, Any]
 	"""
@@ -451,6 +447,10 @@ class InstallationDirective(SphinxDirective):
 	def run_html(self) -> List[nodes.Node]:
 		"""
 		Generate output for ``HTML`` builders.
+
+		:rtype:
+
+		.. latex:clearpage::
 		"""
 
 		targetid = f'installation-{self.env.new_serialno("sphinx-toolbox installation"):d}'
@@ -459,8 +459,8 @@ class InstallationDirective(SphinxDirective):
 		content = make_installation_instructions(self.options, self.env)
 		view = ViewList(content)
 
-		installation_node = nodes.paragraph(rawsource=content)  # type: ignore
-		self.state.nested_parse(view, self.content_offset, installation_node)  # type: ignore
+		installation_node = nodes.paragraph(rawsource=content)  # type: ignore[arg-type]
+		self.state.nested_parse(view, self.content_offset, installation_node)  # type: ignore[arg-type]
 		installation_node_purger.add_node(self.env, installation_node, targetnode, self.lineno)
 
 		return [targetnode, installation_node]
@@ -489,8 +489,8 @@ class InstallationDirective(SphinxDirective):
 			installation_node_purger.add_node(self.env, section, targetnode, self.lineno)
 
 			view = ViewList(tab_content)
-			paragraph_node = nodes.paragraph(rawsource=tab_content)  # type: ignore
-			self.state.nested_parse(view, self.content_offset, paragraph_node)  # type: ignore
+			paragraph_node = nodes.paragraph(rawsource=tab_content)  # type: ignore[arg-type]
+			self.state.nested_parse(view, self.content_offset, paragraph_node)  # type: ignore[arg-type]
 			nodes_to_return.append(paragraph_node)
 			installation_node_purger.add_node(self.env, paragraph_node, targetnode, self.lineno)
 
@@ -564,7 +564,7 @@ class ExtensionsDirective(SphinxDirective):
 
 	has_content: bool = True  # Other required extensions, one per line
 	optional_arguments: int = 1  # The name of the project
-	option_spec: OptionSpec = {  # type: ignore
+	option_spec: OptionSpec = {  # type: ignore[assignment]
 		"import-name": directives.unchanged_required,  # If different to project name
 		"no-preamble": flag,
 		"no-postamble": flag,
@@ -574,6 +574,10 @@ class ExtensionsDirective(SphinxDirective):
 	def run(self) -> List[nodes.Node]:
 		"""
 		Create the extensions node.
+
+		:rtype:
+
+		.. latex:clearpage::
 		"""
 
 		extensions = list(self.content)
@@ -627,8 +631,8 @@ class ExtensionsDirective(SphinxDirective):
 		if "no-postamble" not in self.options:
 			content.extend([bottom_text, ''])
 
-		extensions_node = nodes.paragraph(rawsource=content)  # type: ignore
-		self.state.nested_parse(ViewList(content), self.content_offset, extensions_node)  # type: ignore
+		extensions_node = nodes.paragraph(rawsource=content)  # type: ignore[arg-type]
+		self.state.nested_parse(ViewList(content), self.content_offset, extensions_node)  # type: ignore[arg-type]
 		extensions_node_purger.add_node(self.env, extensions_node, targetnode, self.lineno)
 
 		return [targetnode, extensions_node]
@@ -700,7 +704,7 @@ def copy_asset_files(app: Sphinx, exception: Optional[Exception] = None):
 			])
 
 
-def _on_config_inited(app: Sphinx, config: Config):
+def _on_config_inited(app: Sphinx, config: Config) -> None:
 	app.add_css_file("sphinx_toolbox_installation.css")
 	app.add_js_file("sphinx_toolbox_installation.js")
 
