@@ -11,6 +11,9 @@ Documenters for functions and methods which display overloads differently.
 Configuration
 ----------------
 
+.. latex:vspace:: -20px
+
+
 .. confval:: overloads_location
 	:type: :class:`str`
 	:default: ``'signature'``
@@ -25,10 +28,12 @@ Configuration
 API Reference
 ----------------
 
+.. latex:vspace:: -20px
+
 .. automodulesumm:: sphinx_toolbox.more_autodoc.overloads
 	:autosummary-sections: Classes
 
-.. latex:clearpage::
+.. latex:vspace:: -15px
 
 .. automodulesumm:: sphinx_toolbox.more_autodoc.overloads
 	:autosummary-sections: Functions
@@ -86,8 +91,10 @@ API Reference
 
 # stdlib
 import re
+from contextlib import suppress
 from inspect import Parameter, Signature
-from typing import TYPE_CHECKING, Any, Dict, List
+from types import ModuleType
+from typing import TYPE_CHECKING, Any, Dict, ForwardRef, List
 
 # 3rd party
 from domdf_python_tools.stringlist import StringList
@@ -99,7 +106,7 @@ from sphinx.util import inspect
 from sphinx.util.inspect import evaluate_signature, safe_getattr, stringify_signature
 
 # this package
-from sphinx_toolbox.more_autodoc.typehints import default_preprocessors, format_annotation
+from sphinx_toolbox.more_autodoc.typehints import _resolve_forwardref, default_preprocessors, format_annotation
 from sphinx_toolbox.utils import SphinxExtMetadata, metadata_add_version
 
 if TYPE_CHECKING:
@@ -122,8 +129,6 @@ _return_type_re = re.compile("^:(rtype|return(s)?):")
 class OverloadMixin(_OverloadMixinBase):
 	"""
 	Mixin class for function and class documenters that changes the appearance of overloaded functions.
-
-	.. versionadded:: 1.4.0
 	"""
 
 	def create_body_overloads(self) -> StringList:
@@ -145,7 +150,9 @@ class OverloadMixin(_OverloadMixinBase):
 
 		if self.analyzer and '.'.join(self.objpath) in self.analyzer.overloads:
 
-			for overload in self.analyzer.overloads.get('.'.join(self.objpath)):  # type: ignore
+			the_overloads = self.analyzer.overloads.get('.'.join(self.objpath))
+			assert the_overloads is not None
+			for overload in the_overloads:
 				overload = self.process_overload_signature(overload)
 
 				buf = [format_annotation(self.object), r"\("]
@@ -174,8 +181,19 @@ class OverloadMixin(_OverloadMixinBase):
 					buf[-1] = r")"
 
 				if overload.return_annotation is not Parameter.empty:
+					return_annotation = overload.return_annotation
+
+					if isinstance(return_annotation, ForwardRef):
+						with suppress(Exception):
+							if isinstance(self.parent, ModuleType):
+								module_name = self.parent.__name__
+							else:
+								module_name = self.parent.__module__
+
+							return_annotation = _resolve_forwardref(return_annotation, module_name)
+
 					buf.append(" -> ")
-					buf.append(format_annotation(overload.return_annotation))
+					buf.append(format_annotation(return_annotation))
 
 				formatted_overloads.append(''.join(buf))
 
@@ -281,10 +299,8 @@ class OverloadMixin(_OverloadMixinBase):
 
 class FunctionDocumenter(OverloadMixin, autodoc.FunctionDocumenter):
 	"""
-	Custom :class:`sphinx.ext.autodoc.FunctionDocumenter` which
-	renders overloads differently.
-
-	.. versionadded:: 1.4.0
+	Custom :class:`autodoc.FunctionDocumenter <sphinx.ext.autodoc.FunctionDocumenter>`
+	which renders overloads differently.
 	"""  # noqa: D400
 
 	def format_signature(self, **kwargs: Any) -> str:
@@ -313,12 +329,14 @@ class FunctionDocumenter(OverloadMixin, autodoc.FunctionDocumenter):
 
 					documenter = FunctionDocumenter(self.directive, '')
 					documenter.object = func
-					documenter.objpath = [None]  # type: ignore
+					documenter.objpath = [None]  # type: ignore[list-item]
 					sigs.append(documenter.format_signature())
 
 		if overloaded:
 			if self.env.config.overloads_location == "signature":
-				for overload in self.analyzer.overloads.get('.'.join(self.objpath)):  # type: ignore
+				the_overloads = self.analyzer.overloads.get('.'.join(self.objpath))
+				assert the_overloads is not None
+				for overload in the_overloads:
 					sig = stringify_signature(self.process_overload_signature(overload), **kwargs)
 					sigs.append(sig)
 
@@ -354,10 +372,8 @@ class FunctionDocumenter(OverloadMixin, autodoc.FunctionDocumenter):
 
 class MethodDocumenter(OverloadMixin, autodoc.MethodDocumenter):
 	"""
-	Custom :class:`sphinx.ext.autodoc.MethodDocumenter` which
-	renders overloads differently.
-
-	.. versionadded:: 1.4.0
+	Custom :class:`autodoc.MethodDocumenter <sphinx.ext.autodoc.MethodDocumenter>`
+	which renders overloads differently.
 	"""  # noqa: D400
 
 	def format_signature(self, **kwargs: Any) -> str:
@@ -390,12 +406,14 @@ class MethodDocumenter(OverloadMixin, autodoc.MethodDocumenter):
 					documenter = MethodDocumenter(self.directive, '')
 					documenter.parent = self.parent
 					documenter.object = func
-					documenter.objpath = [None]  # type: ignore
+					documenter.objpath = [None]  # type: ignore[list-item]
 					sigs.append(documenter.format_signature())
 
 		if overloaded:
 			if self.env.config.overloads_location == "signature":
-				for overload in self.analyzer.overloads.get('.'.join(self.objpath)):  # type: ignore
+				the_overloads = self.analyzer.overloads.get('.'.join(self.objpath))
+				assert the_overloads is not None
+				for overload in the_overloads:
 					sig = stringify_signature(self.process_overload_signature(overload), **kwargs)
 					sigs.append(sig)
 
@@ -422,10 +440,6 @@ class MethodDocumenter(OverloadMixin, autodoc.MethodDocumenter):
 		Processes the signature of the given overloaded implementation.
 
 		:param overload:
-
-		:rtype:
-
-		.. latex:clearpage::
 		"""
 
 		__globals__ = safe_getattr(self.object, "__globals__", {})
@@ -442,8 +456,6 @@ def setup(app: Sphinx) -> SphinxExtMetadata:
 	"""
 	Setup :mod:`sphinx_toolbox.more_autodoc.overloads`.
 
-	.. versionadded:: 1.4.0
-
 	:param app: The Sphinx application.
 	"""
 
