@@ -35,12 +35,15 @@ option in ``conf.py``, or with the :rst:dir:`:sourcelink: <sourcelink>` option f
 	When passed as an option flag to an :rst:dir:`automodule` directive,
 	show a link to the corresponding source code at the top of the output *for that module only*.
 
+.. latex:vspace:: 5px
 
 .. versionchanged:: 1.1.0
 
 	Added support for the :rst:dir:`:sourcelink: <sourcelink>` option flag to :rst:dir:`automodule`.
 
 
+.. latex:clearpage::
+
 API Reference
 --------------
 
@@ -73,7 +76,7 @@ from types import ModuleType
 from typing import Any, List, Mapping
 
 # 3rd party
-import autodocsumm  # type: ignore
+import autodocsumm  # type: ignore[import]
 import sphinx.ext.autodoc
 from sphinx.application import Sphinx
 
