@@ -46,6 +46,8 @@ The changes are:
           docstring_hooks.append((my_hook, 75))
           return {}
 
+  .. latex:clearpage::
+
   ``my_hook`` is a function that takes the object being documented as its only argument
   and returns that object after modification. The ``75`` is the priority of the hook:
 
@@ -119,19 +121,26 @@ import types
 from contextlib import suppress
 from tempfile import TemporaryDirectory
 from types import FunctionType, ModuleType
-from typing import Any, AnyStr, Callable, Dict, List, NewType, Optional, Tuple, Type, TypeVar, get_type_hints
-
-# 3rd party
-from domdf_python_tools.stringlist import DelimitedList
-
-if sys.version_info < (3, 7, 4):  # pragma: no cover (py37+)
-	# stdlib
-	from typing import _ForwardRef as ForwardRef  # type: ignore
-else:  # pragma: no cover (<py37)
-	from typing import ForwardRef  # type: ignore
+from typing import (
+		Any,
+		AnyStr,
+		Callable,
+		Dict,
+		ForwardRef,
+		List,
+		NewType,
+		Optional,
+		Tuple,
+		Type,
+		TypeVar,
+		Union,
+		get_type_hints
+		)
 
 # 3rd party
+import sphinx.util.typing
 import sphinx_autodoc_typehints
+from domdf_python_tools.stringlist import DelimitedList
 from domdf_python_tools.typing import (
 		ClassMethodDescriptorType,
 		MethodDescriptorType,
@@ -302,6 +311,8 @@ def format_annotation(annotation, fully_qualified: bool = False) -> str:
 	:rtype:
 
 	.. versionchanged:: 2.13.0  Added support for :py:obj:`True` and :py:obj:`False`
+
+	.. latex:clearpage::
 	"""
 
 	prefix = '' if fully_qualified else '~'
@@ -368,6 +379,8 @@ def format_annotation(annotation, fully_qualified: bool = False) -> str:
 	# Redirect all typing_extensions types to the stdlib typing module
 	elif module == "typing_extensions":
 		module = "typing"
+	elif module == "typing" and class_name == "AbstractContextManager":
+		module = "contextlib"
 
 	full_name = (f"{module}.{class_name}") if module != "builtins" else class_name
 	prefix = '' if fully_qualified or full_name == class_name else '~'
@@ -503,9 +516,10 @@ def preprocess_class_defaults(
 			else:
 				if hasattr(obj, "__attrs_attrs__") and default is attr.NOTHING:
 					# Special casing for attrs classes
-					for value in obj.__attrs_attrs__:  # type: ignore
-						if value.name == argname and isinstance(value.default, attr.Factory):  # type: ignore
-							default = value.default.factory()
+					for value in obj.__attrs_attrs__:  # type: ignore[attr-defined]
+						if value.name == argname:
+							if isinstance(value.default, attr.Factory):  # type: ignore[arg-type]
+								default = value.default.factory()
 
 		parameters.append(param.replace(annotation=inspect.Parameter.empty, default=default))
 
@@ -676,8 +690,6 @@ def process_docstring(
 	.. versionchanged:: 1.1.0
 
 		An empty ``:rtype:`` flag can be used to control the position of the return type annotation in the docstring.
-
-	.. clearpage::
 	"""
 
 	if what in {"variable", "regex"}:
@@ -872,3 +884,25 @@ def setup(app: Sphinx) -> SphinxExtMetadata:
 	app.add_config_value("hide_none_rtype", False, "env", [bool])
 
 	return {"parallel_read_safe": True}
+
+
+def _resolve_forwardref(
+		fr: Union[ForwardRef, sphinx.util.typing.ForwardRef],
+		module: str,
+		) -> object:
+	"""
+	Resolve a forward reference.
+
+	This is not part of the public API.
+
+	:param fr:
+	:param module: The module the forward reference was defined in.
+
+	:return: The evaluated object.
+	"""
+
+	module_dict = sys.modules[module].__dict__
+	if sys.version_info < (3, 9):
+		return fr._evaluate(module_dict, module_dict)
+	else:
+		return fr._evaluate(module_dict, module_dict, set())
