@@ -29,13 +29,11 @@ Configuration
 	This option has no effect if :confval:`all_typevars` is False.
 
 
-.. latex:vspace:: -15px
+.. latex:clearpage::
 
 Usage
 ----------
 
-.. latex:vspace:: -10px
-
 .. rst:directive:: autotypevar
 
 	Directive to automatically document a :class:`typing.TypeVar`.
@@ -112,8 +110,7 @@ API Reference
 
 # stdlib
 import sys
-from types import ModuleType
-from typing import Any, Dict, List, Optional, Tuple, Type, TypeVar, Union
+from typing import Any, Dict, ForwardRef, List, Optional, Tuple, Type, TypeVar, Union
 
 # 3rd party
 from domdf_python_tools.words import word_join
@@ -123,7 +120,7 @@ from typing_extensions import Protocol
 # this package
 from sphinx_toolbox._data_documenter import DataDocumenter
 from sphinx_toolbox.config import ToolboxConfig
-from sphinx_toolbox.more_autodoc.typehints import ForwardRef, format_annotation
+from sphinx_toolbox.more_autodoc.typehints import format_annotation
 from sphinx_toolbox.more_autodoc.variables import VariableDocumenter
 from sphinx_toolbox.utils import SphinxExtMetadata, metadata_add_version
 
@@ -173,15 +170,9 @@ class TypeVarDocumenter(VariableDocumenter):
 		"""
 
 		if forward_ref.__forward_evaluated__:
-			return forward_ref.__forward_value__
+			return forward_ref.__forward_value__  # type: ignore
 		else:
-			if sys.version_info[:2] == (3, 6) and self.object.__module__ == "typing" and isinstance(
-					self.parent, ModuleType
-					):
-				# __module__ is 'typing' for 3.6
-				globanls = self.parent.__dict__
-			else:
-				globanls = sys.modules[self.object.__module__].__dict__
+			globanls = sys.modules[self.object.__module__].__dict__
 
 			eval_ = eval
 			return eval_(forward_ref.__forward_code__, globanls, globanls)
@@ -270,7 +261,7 @@ class TypeVarDocumenter(VariableDocumenter):
 
 		super().add_directive_header(sig)
 
-	def get_doc(  # type: ignore
+	def get_doc(  # type: ignore[override]
 			self,
 			encoding: Optional[str] = None,
 			ignore: Optional[int] = None,
@@ -280,6 +271,10 @@ class TypeVarDocumenter(VariableDocumenter):
 
 		:param encoding:
 		:param ignore:
+
+		:rtype:
+
+		.. latex:clearpage::
 		"""
 
 		if self.object.__doc__ != TypeVar.__doc__:
