@@ -98,6 +98,7 @@ API Reference
 import importlib
 import sys
 import warnings
+from contextlib import suppress
 from typing import Any, List, Optional, cast, get_type_hints
 
 # 3rd party
@@ -128,7 +129,7 @@ from sphinx.util.inspect import ForwardRef, object_description, safe_getattr
 
 # this package
 from sphinx_toolbox._data_documenter import DataDocumenter
-from sphinx_toolbox.more_autodoc.typehints import format_annotation
+from sphinx_toolbox.more_autodoc.typehints import _resolve_forwardref, format_annotation
 from sphinx_toolbox.utils import SphinxExtMetadata, add_nbsp_substitution, flag, metadata_add_version
 
 __all__ = [
@@ -154,12 +155,8 @@ def get_variable_type(documenter: Documenter) -> str:
 	except NameError:
 		# Failed to evaluate ForwardRef (maybe TYPE_CHECKING)
 		annotations = safe_getattr(documenter.parent, "__annotations__", {})
-	except TypeError:
-		annotations = {}
-	except KeyError:
-		# a broken class found (refs: https://github.com/sphinx-doc/sphinx/issues/8084)
-		annotations = {}
-	except AttributeError:
+	except (TypeError, KeyError, AttributeError):
+		# KeyError: a broken class found (refs: https://github.com/sphinx-doc/sphinx/issues/8084)
 		# AttributeError is raised on 3.5.2 (fixed by 3.5.3)
 		annotations = {}
 
@@ -184,10 +181,9 @@ def get_variable_type(documenter: Documenter) -> str:
 				if annotation.isidentifier() and annotation in module_dict:
 					return format_annotation(module_dict[annotation])
 				else:
-					if sys.version_info < (3, 9):
-						return format_annotation(ForwardRef(annotation)._evaluate(module_dict, module_dict))
-					else:
-						return format_annotation(ForwardRef(annotation)._evaluate(module_dict, module_dict, set()))
+					ref = ForwardRef(annotation)
+					evaled = _resolve_forwardref(ref, documenter.parent.__module__)
+					return format_annotation(evaled)
 
 			except (NameError, TypeError, ValueError, AttributeError):
 				return annotation
@@ -204,6 +200,10 @@ Renders like:
 
 	**Type:** |nbsp| |nbsp| |nbsp| |nbsp| :class:`str`
 
+.. note::
+
+	Be sure to call :func:~.add_nbsp_substitution` in the ``setup`` function
+	of any extensions using this template.
 """
 
 
@@ -226,6 +226,7 @@ class VariableDocumenter(DataDocumenter):
 	def __init__(self, directive: DocumenterBridge, name: str, indent: str = '') -> None:
 		super().__init__(directive=directive, name=name, indent=indent)
 		self.options = Options(self.options.copy())
+		add_nbsp_substitution(self.env.app.config)
 
 	def add_directive_header(self, sig: str):
 		"""
@@ -246,12 +247,10 @@ class VariableDocumenter(DataDocumenter):
 				if "value" in self.options:
 					self.add_line(f"   :value: {self.options['value']}", sourcename)
 				else:
-					try:
+					with suppress(ValueError):
 						if self.object is not UNINITIALIZED_ATTR:
 							objrepr = object_description(self.object)
 							self.add_line(f"   :value: {objrepr}", sourcename)
-					except ValueError:
-						pass
 
 			self.add_line('', sourcename)
 
@@ -281,7 +280,8 @@ class VariableDocumenter(DataDocumenter):
 
 class TypedAttributeDocumenter(DocstringStripSignatureMixin, ClassLevelDocumenter):
 	"""
-	Alternative version of :class:`sphinx.ext.autodoc.AttributeDocumenter`
+	Alternative version of
+	:class:`autodoc.AttributeDocumenter <sphinx.ext.autodoc.AttributeDocumenter>`
 	with better type hint rendering.
 
 	Specialized Documenter subclass for attributes.
@@ -403,12 +403,10 @@ class TypedAttributeDocumenter(DocstringStripSignatureMixin, ClassLevelDocumente
 				if "value" in self.options:
 					self.add_line("   :value: " + self.options["value"], sourcename)
 				else:
-					try:
+					with suppress(ValueError):
 						if self.object is not INSTANCEATTR:
 							objrepr = object_description(self.object)
 							self.add_line("   :value: " + objrepr, sourcename)
-					except ValueError:
-						pass
 
 			self.add_line('', sourcename)
 
@@ -435,7 +433,7 @@ class TypedAttributeDocumenter(DocstringStripSignatureMixin, ClassLevelDocumente
 		else:
 			super().add_directive_header(sig)
 
-	def get_doc(  # type: ignore
+	def get_doc(  # type: ignore[override]
 			self,
 			encoding: Optional[str] = None,
 			ignore: Optional[int] = None,
@@ -447,12 +445,13 @@ class TypedAttributeDocumenter(DocstringStripSignatureMixin, ClassLevelDocumente
 		:param ignore:
 		"""
 
+		# Disable `autodoc_inherit_docstring` temporarily to avoid to obtain
+		# a docstring from the value which descriptor returns unexpectedly.
+		# ref: https://github.com/sphinx-doc/sphinx/issues/7805
+		orig = self.env.config.autodoc_inherit_docstrings
+
 		try:
-			# Disable `autodoc_inherit_docstring` temporarily to avoid to obtain
-			# a docstring from the value which descriptor returns unexpectedly.
-			# ref: https://github.com/sphinx-doc/sphinx/issues/7805
-			orig = self.env.config.autodoc_inherit_docstrings
-			self.env.config.autodoc_inherit_docstrings = False  # type: ignore
+			self.env.config.autodoc_inherit_docstrings = False  # type: ignore[attr-defined]
 
 			# Sphinx's signature is wrong wrt Optional
 			if sphinx.version_info >= (4, 0):
@@ -461,9 +460,13 @@ class TypedAttributeDocumenter(DocstringStripSignatureMixin, ClassLevelDocumente
 				else:
 					return super().get_doc(ignore=cast(int, ignore)) or []
 			else:
-				return super().get_doc(cast(str, encoding), cast(int, ignore)) or []  # type: ignore
+				super_get_doc = super().get_doc(  # type: ignore[call-arg]
+					cast(str, encoding),  # type: ignore[arg-type]
+					cast(int, ignore),
+					)
+				return super_get_doc or []
 		finally:
-			self.env.config.autodoc_inherit_docstrings = orig  # type: ignore
+			self.env.config.autodoc_inherit_docstrings = orig  # type: ignore[attr-defined]
 
 	def add_content(self, more_content: Any, no_docstring: bool = False) -> None:
 		"""
@@ -483,7 +486,8 @@ class TypedAttributeDocumenter(DocstringStripSignatureMixin, ClassLevelDocumente
 
 class InstanceAttributeDocumenter(TypedAttributeDocumenter):
 	"""
-	Alternative version of :class:`sphinx.ext.autodoc.InstanceAttributeDocumenter`
+	Alternative version of
+	:class:`autodoc.InstanceAttributeDocumenter <sphinx.ext.autodoc.InstanceAttributeDocumenter>`
 	with better type hint rendering.
 
 	Specialized Documenter subclass for attributes that cannot be imported
@@ -559,7 +563,8 @@ class InstanceAttributeDocumenter(TypedAttributeDocumenter):
 
 class SlotsAttributeDocumenter(TypedAttributeDocumenter):
 	r"""
-	Alternative version of :class:`sphinx.ext.autodoc.InstanceAttributeDocumenter`
+	Alternative version of
+	:class:`autodoc.InstanceAttributeDocumenter <sphinx.ext.autodoc.InstanceAttributeDocumenter>`
 	with better type hint rendering.
 
 	Specialized Documenter subclass for attributes that cannot be imported
@@ -629,7 +634,7 @@ class SlotsAttributeDocumenter(TypedAttributeDocumenter):
 					self.env.note_reread()
 					return False
 
-	def get_doc(  # type: ignore
+	def get_doc(  # type: ignore[override]
 			self,
 			encoding: Optional[str] = None,
 			ignore: Optional[int] = None,
@@ -673,6 +678,6 @@ def setup(app: Sphinx) -> SphinxExtMetadata:
 	app.add_autodocumenter(InstanceAttributeDocumenter, override=True)
 	app.add_autodocumenter(SlotsAttributeDocumenter, override=True)
 
-	add_nbsp_substitution(app.config)
+	app.connect("config-inited", lambda _, config: add_nbsp_substitution(config))
 
 	return {"parallel_read_safe": True}
