@@ -33,6 +33,8 @@ and created a broken link.
 Configuration
 --------------
 
+.. latex:vspace:: -20px
+
 .. confval:: autodocsumm_member_order
 	:type: :py:obj:`str`
 	:default: ``'alphabetical'``
@@ -71,8 +73,6 @@ Configuration
 	.. versionadded:: 2.13.0
 
 
-.. latex:clearpage::
-
 
 API Reference
 ----------------
@@ -150,7 +150,7 @@ import re
 from typing import Any, List, Optional, Tuple, Type
 
 # 3rd party
-import autodocsumm  # type: ignore
+import autodocsumm  # type: ignore[import]
 import sphinx
 from docutils import nodes
 from domdf_python_tools.stringlist import StringList
@@ -309,10 +309,6 @@ class PatchedAutosummary(Autosummary):
 
 			Now selects the appropriate documenter for attributes rather than
 			falling back to :class:`~sphinx.ext.autodoc.DataDocumenter`.
-
-		:rtype:
-
-		.. clearpage::
 		"""
 
 		doccls = get_documenter(app, obj, parent)
@@ -322,7 +318,11 @@ class PatchedAutosummary(Autosummary):
 		"""
 		Generate a list of table nodes for the :rst:dir:`autosummary` directive.
 
-		:param items: A list  produced by ``self.get_items``.
+		:param items: A list produced by ``self.get_items``.
+
+		:rtype:
+
+		.. latex:clearpage::
 		"""
 
 		table_spec, *other_nodes = super().get_table(items)
@@ -429,10 +429,7 @@ class PatchedAutoSummModuleDocumenter(autodocsumm.AutoSummModuleDocumenter):
 		# process members and determine which to skip
 		for (membername, member) in members:
 			# if isattr is True, the member is documented as an attribute
-			if member is INSTANCEATTR or (namespace, membername) in attr_docs:
-				isattr = True
-			else:
-				isattr = False
+			isattr = (member is INSTANCEATTR or (namespace, membername) in attr_docs)
 
 			doc = getdoc(
 					member,
@@ -454,9 +451,9 @@ class PatchedAutoSummModuleDocumenter(autodocsumm.AutoSummModuleDocumenter):
 					doc = None
 
 			if sphinx.version_info > (4, 1):
-				doc, metadata = separate_metadata(doc)  # type: ignore
+				doc, metadata = separate_metadata(doc)  # type: ignore[arg-type]
 			else:
-				metadata = extract_metadata(doc)  # type: ignore
+				metadata = extract_metadata(doc)  # type: ignore[arg-type]
 
 			has_doc = bool(doc)
 
@@ -650,6 +647,7 @@ def setup(app: Sphinx) -> SphinxExtMetadata:
 
 	app.setup_extension("sphinx.ext.autosummary")
 	app.setup_extension("autodocsumm")
+	app.setup_extension("sphinx_toolbox.latex")
 
 	app.add_directive("autosummary", PatchedAutosummary, override=True)
 	app.add_directive("autoclasssumm", PatchedAutoDocSummDirective, override=True)
